# richpride

A collection of pride flag emojis for use with the Rich library.

## Installation

To install the `richpride` package, use pip:

```bash
pip install richpride
```

## Usage

To use the `richpride` package, simply import the module into your code, and all available flags will work.

Here’s an example of how to use the flags:

```python
import richpride
from rich import print

# Print the trans flag in block form
print(":trans_flag_block:")

# Print the pride flag in block form
print(":pride_flag_block:")

# You can use other flags in the same way!
# Example: :nonbinary_flag_block:, :genderfluid_flag_block:, etc.
```

To list all currently available flags, use the `list_flags()` function:

```python
import richpride

# List all available flags
richpride.list_flags()
# For trans_flag_ascii, it will be printed as :trans_flag_ascii:
```

To list all currently available flags in emoji form, use the `list_emojis()` function:

```python
import richpride

# List all available flags as emojis
richpride.list_emojis()
# For trans_flag_ascii, it will be printed as [💙💗🤍💗💙]
```

### Flags Available:

-   `:trans_flag:`
-   `:trans_flag_alt:`
-   `:trans_flag_ascii:`
-   `:trans_flag_ascii_alt:`
-   `:trans_flag_block:`
-   `:trans_flag_block_alt:`
-   `:pride_flag:`
-   `:pride_flag_alt:`
-   `:pride_flag_ascii:`
-   `:pride_flag_ascii_alt:`
-   `:pride_flag_block:`
-   `:pride_flag_block_alt:`
-   `:nonbinary_flag_ascii:`
-   `:nonbinary_flag_ascii_alt:`
-   `:nonbinary_flag_block:`
-   `:nonbinary_flag_block_alt:`
-   `:genderfluid_flag_ascii:`
-   `:genderfluid_flag_ascii_alt:`
-   `:genderfluid_flag_block:`
-   `:genderfluid_flag_block_alt:`
-   `:pansexual_flag_ascii:`
-   `:pansexual_flag_ascii_alt:`
-   `:pansexual_flag_block:`
-   `:pansexual_flag_block_alt:`
-   `:asexual_flag_ascii:`
-   `:asexual_flag_ascii_alt:`
-   `:asexual_flag_block:`
-   `:asexual_flag_block_alt:`
-   `:bisexual_flag_ascii:`
-   `:bisexual_flag_ascii_alt:`
-   `:bisexual_flag_block:`
-   `:bisexual_flag_block_alt:`
-   `:lesbian_flag_ascii:`
-   `:lesbian_flag_ascii_alt:`
-   `:lesbian_flag_block:`
-   `:lesbian_flag_block_alt:`
-   `:agender_flag_ascii:`
-   `:agender_flag_ascii_alt:`
-   `:agender_flag_block:`
-   `:agender_flag_block_alt:`
-   `:genderqueer_flag_ascii:`
-   `:genderqueer_flag_ascii_alt:`
-   `:genderqueer_flag_block:`
-   `:genderqueer_flag_block_alt:`
